% This code is to run calculate which model parameter has the greatest influence on lambda (elasticity analysis):
% 1. first read in the 8 parameters required to parameterise a DEB-IPM
% 2. then call DEBIPMNotShrink_sens.m to calculate which parameter is most
% sensitive (this function file calls BigMatrixShrink_MicroOrg where the IPM is
% calculated)

% parameters perturbed are in this order: Lb, Lp, Lm, Rm, rb, mu_adult, mu_juv

% MostSensPar is an index value identifying which parameter is the most
% influential to the population growth rate. For example, if MostSensPar
% = 1, then Lb is the parameter that has the highest influence on lambda.
% If MostSensPar = 7, then juvenile mortality rate has the highest influence on lambda.

% make sure your working path is the folder that contains all files extracted from Figshare

warning('off')

% MatrixSize: number of size bins of matrix approximation of DEBIPM. suggestion: 200
% Lm,Lp,lowval (Lb) and rb are retrieved from local .txt files 

MatrixSize = 200;

% Read in the data 
Inputdata= readtable('InputData.txt'); 

%Create list of all species id's
all_id = Inputdata.RecordID;

%Create loop over all species id's
for i = [1:length(all_id)]
    id = all_id(i);
    
    %Find E_Y of id
    E_Y = Inputdata.E_Y(i);
    
    %Find Lb id
    Lb = Inputdata.Lb(i);
    
    %Find Lp of id
    Lp = Inputdata.Lp(i);
    
    %Find Lm of id
    Lm = Inputdata.Lm(i);
    
    %Find Rm of id
    Rm = Inputdata.Rm(i);
      
    %Find rb of id
    rb = Inputdata.rB(i);
    
    %Find kappa of id
    kappa = Inputdata.kappa(i);
    
    %Find mu_juv of id
    mu_juv = Inputdata.mu_juv(i);
    
    %Find mu_adult of id
    mu_ad = Inputdata.mu_adult(i);
      
    %Calculate SSD & PopQs for each value of E_Y
    Parameter = DEBIPMNotShrink_sens(E_Y,MatrixSize,Lp,rb,Rm,Lm,kappa,Lb,mu_juv,mu_ad);
    MostSensPars(i,:) = Parameter;  
   
end

MostSensPars = [all_id, MostSensPars]; % add species IDs