% This code is to run the DEB-IPM over multiple species in two steps:
% 1. first it reads in the 8 parameters required to parameterise a DEB-IPM
% 2. then calls on DEBIPMNotShrink_Macroorganism.m to calculate IPM outputs
% (this function file calls BigMatrixNotShrink where the IPM is calculated)

% make sure your working path is the folder that contains all files extracted from Figshare

warning('off')

% MatrixSize: number of size bins of matrix approximation of DEBIPM. suggestion: 200
% Lm,Lp,lowval (Lb) and rb are retrieved from local .txt files 

MatrixSize = 200;

% Read in the data 
Inputdata= readtable('InputData.txt'); 

%Create list of all species id's
all_id = Inputdata.RecordID;

%Create loop over all species id's
for i = [1:length(all_id)]
    id = all_id(i); 
    
    %Find E_Y of id
    E_Y = Inputdata.E_Y(i);
    
    %Find Lb id
    clear Lb, Lb = Inputdata.Lb(i);
    
    %Find Lp of id
    clear Lp, Lp = Inputdata.Lp(i);
    
    %Find Lm of id
    clear Lm, Lm = Inputdata.Lm(i);
    
    %Find Rm of id
    clear Rm, Rm = Inputdata.Rm(i);
      
    %Find rb of id
    clear rb, rb = Inputdata.rB(i);
    
    %Find kappa of id
    clear kappa, kappa = Inputdata.k(i);
    
    %Find mu_juv of id
    clear mu_juv, mu_juv = Inputdata.mj(i);
    
    %Find mu_adult of id
    clear mu_ad, mu_ad = Inputdata.ma(i);
     
    %Calculate life history traits 
    PopQs = DEBIPMNotShrink_Macroorganism(E_Y,MatrixSize,Lb,Lp,Lm,Rm,rb,kappa,mu_juv,mu_ad);
        
    LHtraits(i,:) = PopQs;  
   
end

LHtraits = [all_id, LHtraits]; % add species IDs
header = {'RecordID','E_Y', 'GT_approx', 'SurvivorCurve', 'L_alpha', 'Proggrowth',...
    'Retrogrowth', 'Phi', 'DegreeItero', 'NetReprRate', 'L_omega', 'lambda', 'dampingratio'};
LHtraits = [header; num2cell(LHtraits)]; % add headers
