clear all; close all

%% Read in the data 
Validationdata= readtable('ValidationData.txt'); 

% first remove greenland shark in row 42, 
% which is an outlier in terms of life history trait values

Validationdata([42],:) = [];

%Create list of all species id's
all_id = Validationdata.RecordID;

%Extract lambda values for feeding level E(Y)=0.9
all_lambda_EY09 = Validationdata.lambda_EY09; 

%Extract predicted generation times for feeding level E(Y)=0.9
all_GTPred_EY09 = Validationdata.GenerationTimePred_EY09;

%Extract predicted longevity for feeding level E(Y)=0.9
all_LongevityPred_EY09 = Validationdata.LongevityPred_EY09;

%Extract predicted age at maturity for feeding level E(Y)=0.9
all_AgeAtMatPred_EY09 = Validationdata.AgeAtMaturityPred_EY09;

%Extract lambda values for feeding level E(Y)=0.7
all_lambda_EY07 = Validationdata.lambda_EY07;

%Extract predicted generation times for feeding level E(Y)=0.7
all_GTPred_EY07 = Validationdata.GenerationTimePred_EY07;

%Extract predicted longevity for feeding level E(Y)=0.7
all_LongevityPred_EY07 = Validationdata.LongevityPred_EY07;

%Extract predicted age at maturity for feeding level E(Y)=0.7
all_AgeAtMatPred_EY07 = Validationdata.AgeAtMaturityPred_EY07;

%Extract lambda values for feeding level E(Y)=0.5
all_lambda_EY05 = Validationdata.lambda_EY05;

%Extract predicted generation times for feeding level E(Y)=0.5
all_GTPred_EY05 = Validationdata.GenerationTimePred_EY05;

%Extract predicted longevity for feeding level E(Y)=0.5
all_LongevityPred_EY05 = Validationdata.LongevityPred_EY05;

%Extract predicted age at maturity for feeding level E(Y)=0.5
all_AgeAtMatPred_EY05 = Validationdata.AgeAtMaturityPred_EY05;

%Extract observed generation times
all_GT = Validationdata.GenerationTime;

%Extract observed longevity
all_Longevity = Validationdata.MeanMaxAge;

%Extract observed age at maturity
all_AgeAtMat = Validationdata.AgeAtMaturity;

%% plot predicted and observed values

subplot(2,2,1)
histogram(all_lambda_EY09,20); 
hold on
histogram(all_lambda_EY07,20); axis square
histogram(all_lambda_EY05,20); axis square
xlabel ('Population growth rate','FontSize',14); ylabel('Frequency','FontSize',14)
legend('E(Y) = 0.9','E(Y) = 0.7','E(Y) = 0.5')
txt = 'A';
text(0.3,113,txt,'FontSize',12)
hold off

subplot(2,2,2)
plot(all_GT,all_GTPred_EY09,'b^','MarkerSize',5,'LineWidth',1.3)
hold on
plot(all_GT,all_GTPred_EY07,'ro','MarkerSize',5,'LineWidth',1.3); 
plot(all_GT,all_GTPred_EY05,'*','Marker','square','MarkerSize',5,"MarkerEdgeColor",[0.9290 0.6940 0.1250],'LineWidth',1.3); 
plot([0 100],[0 100],'k-')
axis square;  axis([0 100 0 100])
xlabel ('Observed generation time','FontSize',14); ylabel('Predicted generation time','FontSize',14);
legend('E(Y) = 0.9','E(Y) = 0.7','E(Y) = 0.5')
txt = 'B';
text(5,94,txt,'FontSize',12)
hold off

subplot(2,2,3)
plot(all_Longevity,all_LongevityPred_EY09,'b^', 'MarkerSize',5,'LineWidth',1.3)
hold on
plot(all_Longevity,all_LongevityPred_EY07,'ro','MarkerSize',5,'LineWidth',1.3); 
plot(all_Longevity,all_LongevityPred_EY05,'*','Marker','square','MarkerSize',5,"MarkerEdgeColor",[0.9290 0.6940 0.1250],'LineWidth',1.3); 
plot([0 120],[0 120],'k-')
axis square;  axis([0 120 0 120])
xlabel ('Observed longevity','FontSize',14); ylabel('Predicted longevity','FontSize',14);
legend('E(Y) = 0.9','E(Y) = 0.7','E(Y) = 0.5')
txt = 'C';
text(5,110,txt,'FontSize',12)
hold off

subplot(2,2,4)
plot(all_AgeAtMat,all_AgeAtMatPred_EY09,'b^', 'MarkerSize',5,'LineWidth',1.3)
hold on
plot(all_AgeAtMat,all_AgeAtMatPred_EY07,'ro','MarkerSize',5,'LineWidth',1.3); 
plot(all_AgeAtMat,all_AgeAtMatPred_EY05,'*','Marker','square','MarkerSize',5,"MarkerEdgeColor",[0.9290 0.6940 0.1250],'LineWidth',1.3); 
plot([0 60],[0 60],'k-')
axis square;  axis([0 60 0 60])
xlabel ('Observed age at maturity','FontSize',14); ylabel('Predicted age at maturity','FontSize',14); 
legend('E(Y) = 0.9','E(Y) = 0.7','E(Y) = 0.5')
txt = 'D';
text(3,45,txt,'FontSize',12)
hold off

%% stats: linear models for each feeding level separately, including the root mean square error and R2 value

md_GT_EY09 = fitlm(all_GT,all_GTPred_EY09,'Intercept',false)
R2_md_GT_EY09 = corrcoef(all_GT,all_GTPred_EY09,'rows','complete'); R2_md_GT_EY09 = R2_md_GT_EY09(1,2)^2
md_GT_EY07 = fitlm(all_GT,all_GTPred_EY07,'Intercept',false)
R2_md_GT_EY07 = corrcoef(all_GT,all_GTPred_EY07,'rows','complete'); R2_md_GT_EY07 = R2_md_GT_EY07(1,2)^2
md_GT_EY05 = fitlm(all_GT,all_GTPred_EY05,'Intercept',false)
R2_md_GT_EY05 = corrcoef(all_GT,all_GTPred_EY05,'rows','complete'); R2_md_GT_EY05 = R2_md_GT_EY05(1,2)^2

md_Longevity_EY09 = fitlm(all_Longevity,all_LongevityPred_EY09,'Intercept',false)
R2_md_Longevity_EY09 = corrcoef(all_Longevity,all_LongevityPred_EY09,'rows','complete'); R2_md_Longevity_EY09 = R2_md_Longevity_EY09(1,2)^2
md_Longevity_EY07 = fitlm(all_Longevity,all_LongevityPred_EY07,'Intercept',false)
R2_md_Longevity_EY07 = corrcoef(all_Longevity,all_LongevityPred_EY07,'rows','complete'); R2_md_Longevity_EY07 = R2_md_Longevity_EY07(1,2)^2
md_Longevity_EY05 = fitlm(all_Longevity,all_LongevityPred_EY05,'Intercept',false)
R2_md_Longevity_EY05 = corrcoef(all_Longevity,all_LongevityPred_EY05,'rows','complete'); R2_md_Longevity_EY05 = R2_md_Longevity_EY05(1,2)^2

md_AgeAtMat_EY09 = fitlm(all_AgeAtMat,all_AgeAtMatPred_EY09,'Intercept',false)
R2_md_AgeAtMat_EY09 = corrcoef(all_AgeAtMat,all_AgeAtMatPred_EY09,'rows','complete'); R2_md_AgeAtMat_EY09 = R2_md_AgeAtMat_EY09(1,2)^2
md_AgeAtMat_EY07 = fitlm(all_AgeAtMat,all_AgeAtMatPred_EY07,'Intercept',false)
R2_md_AgeAtMat_EY07 = corrcoef(all_AgeAtMat,all_AgeAtMatPred_EY07,'rows','complete'); R2_md_AgeAtMat_EY07 = R2_md_AgeAtMat_EY07(1,2)^2
md_AgeAtMat_EY05 = fitlm(all_AgeAtMat,all_AgeAtMatPred_EY05,'Intercept',false)
R2_md_AgeAtMat_EY05 = corrcoef(all_AgeAtMat,all_AgeAtMatPred_EY05,'rows','complete'); R2_md_AgeAtMat_EY05 = R2_md_AgeAtMat_EY05(1,2)^2
